==> apache-marmotta-3.2.1-src.zip: apache-marmotta-3.2.1/libraries/ldpath/ldpath-functions-date/src/main/java/org/apache/marmotta/ldpath/model/functions/date/LatestDateFunction.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.marmotta.ldpath.model.functions.date;


import java.util.Collection;
import java.util.Collections;
import java.util.Date;

import org.apache.marmotta.ldpath.api.backend.RDFBackend;
import org.apache.marmotta.ldpath.model.transformers.DateTransformer;

public class LatestDateFunction<Node> extends DateFunction<Node> {

    private final DateTransformer<Node> transformer = new DateTransformer<Node>();

    @Override
    public Collection<Node> apply(RDFBackend<Node> backend, Node context,
            Collection<Node>... args) throws IllegalArgumentException {
        if (args.length != 1) {
            throw new IllegalArgumentException("latest requires exactly one argument");
        }

        Node result = null;
        Date latest = null;

        for (Node node : args[0]) {
            try {
                Date d = transformer.transform(backend, node, null);
                if (latest == null || d.after(latest)) {
                    latest = d;
                    result = node;
                }
            } catch (IllegalArgumentException e) {
                // Non-Date Literals are just ignored
            }
        }

        return result!=null?Collections.singleton(result):Collections.<Node>emptyList();
    }

    @Override
    public String getSignature() {
        return "fn:latest(DateLiteralList): DateLiteral";
    }

    @Override
    public String getDescription() {
        return "select the latest date (max)";
    }

    @Override
    public String getLocalName() {
        return "latest";
    }

}

==> apache-marmotta-3.4.0-src.zip: apache-marmotta-3.4.0/libraries/ldpath/ldpath-functions-date/src/main/java/org/apache/marmotta/ldpath/model/functions/date/LatestDateFunction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.marmotta.ldpath.model.functions.date;


import org.apache.marmotta.ldpath.api.backend.RDFBackend;
import org.apache.marmotta.ldpath.model.transformers.DateTransformer;

import java.util.Collection;
import java.util.Collections;
import java.util.Date;

public class LatestDateFunction<Node> extends DateFunction<Node> {

    private final DateTransformer<Node> transformer = new DateTransformer<>();

    @SafeVarargs
    @Override
    public final Collection<Node> apply(RDFBackend<Node> backend, Node context,
                                        Collection<Node>... args) throws IllegalArgumentException {
        if (args.length != 1) {
            throw new IllegalArgumentException("latest requires exactly one argument");
        }

        Node result = null;
        Date latest = null;

        for (Node node : args[0]) {
            try {
                Date d = transformer.transform(backend, node, null);
                if (latest == null || d.after(latest)) {
                    latest = d;
                    result = node;
                }
            } catch (IllegalArgumentException e) {
                // Non-Date Literals are just ignored
            }
        }

        return result!=null?Collections.singleton(result):Collections.<Node>emptyList();
    }

    @Override
    public String getSignature() {
        return "fn:latest(DateLiteralList): DateLiteral";
    }

    @Override
    public String getDescription() {
        return "select the latest date (max)";
    }

    @Override
    public String getLocalName() {
        return "latest";
    }

}
